==> chevreul_0.99.11.tar.gz: chevreul/inst/doc/chevreul.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    # dev.args = list(png = list(type = "cairo")),
    dpi = 900,
    out.width = "100%",
    message = FALSE,
    warning = FALSE,
    crop = NULL ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
)

## ----vignetteSetup, echo=FALSE, message=FALSE, warning = FALSE----------------
## Track time spent on making the vignette
startTime <- Sys.time()

## Bib setup
library("RefManageR")

## Write bibliography information
bib <- c(
    R = citation(),
    BiocStyle = citation("BiocStyle")[1],
    knitr = citation("knitr")[1],
    RefManageR = citation("RefManageR")[1],
    rmarkdown = citation("rmarkdown")[1],
    sessioninfo = citation("sessioninfo")[1],
    testthat = citation("testthat")[1],
    chevreul = citation("chevreul")[1]
)

## ----"install", eval = FALSE--------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  
#  BiocManager::install("chevreul")
#  
#  ## Check that you have a valid Bioconductor installation
#  BiocManager::valid()

## ----"citation"---------------------------------------------------------------
## Citation info
citation("chevreul")

## ----message=FALSE------------------------------------------------------------

library("chevreul")

# Load the data
chevreul_sce <- chevreuldata::human_gene_transcript_sce()
chevreul_sce

## ----eval=TRUE----------------------------------------------------------------
# Object count matrix
human_count <- counts(chevreul_sce)
human_count[1:5, 1:5] %>% as.matrix() %>% knitr::kable(format = "pipe")

# Object metadata
human_meta <- colData(chevreul_sce) %>% as.data.frame()
human_meta[1:5, 1:5] %>% as.matrix() %>% knitr::kable(format = "pipe")

## -----------------------------------------------------------------------------
myobject <- SingleCellExperiment::SingleCellExperiment(
    assays = list(counts = counts(chevreul_sce)),
    colData = colData(chevreul_sce),
    mainExpName = "gene"
)

myobject

## ----"start", message=FALSE, eval = FALSE-------------------------------------
#  
#  minimalSceApp(chevreul_sce)
#  

## ----createVignette, eval=FALSE-----------------------------------------------
#  ## Create the vignette
#  library("rmarkdown")
#  system.time(render("chevreul.Rmd", "BiocStyle::html_document"))
#  
#  ## Extract the R code
#  library("knitr")
#  knit("chevreul.Rmd", tangle = TRUE)

## ----reproduce1, echo=FALSE---------------------------------------------------
## Date the vignette was generated
Sys.time()

## ----reproduce2, echo=FALSE---------------------------------------------------
## Processing time in seconds
totalTime <- diff(c(startTime, Sys.time()))
round(totalTime, digits = 3)

## ----reproduce3, echo=FALSE-------------------------------------------------------------------------------------------
## Session info
library("sessioninfo")
options(width = 120)
session_info()

## ----vignetteBiblio, results = "asis", echo = FALSE, warning = FALSE, message = FALSE---------------------------------
## Print bibliography
PrintBibliography(bib, .opts = list(hyperlink = "to.doc", style = "html"))

==> chevreul_0.99.18.tar.gz: chevreul/inst/doc/chevreul.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    # dev.args = list(png = list(type = "cairo")),
    dpi = 900,
    out.width = "100%",
    message = FALSE,
    warning = FALSE,
    crop = NULL ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
)

## ----vignetteSetup, echo=FALSE, message=FALSE, warning = FALSE----------------
## Track time spent on making the vignette
startTime <- Sys.time()

## Bib setup
library("RefManageR")

## Write bibliography information
bib <- c(
    R = citation(),
    BiocStyle = citation("BiocStyle")[1],
    knitr = citation("knitr")[1],
    RefManageR = citation("RefManageR")[1],
    rmarkdown = citation("rmarkdown")[1],
    sessioninfo = citation("sessioninfo")[1],
    testthat = citation("testthat")[1],
    chevreul = citation("chevreul")[1]
)

## ----"install", eval = FALSE--------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  
#  BiocManager::install("chevreul")
#  
#  ## Check that you have a valid Bioconductor installation
#  BiocManager::valid()

## ----"citation"---------------------------------------------------------------
## Citation info
citation("chevreul")

## ----message=FALSE------------------------------------------------------------

library("chevreul")

# Load the data
library(chevreuldata)
chevreul_sce <- human_gene_transcript_sce()
chevreul_sce

## ----eval=TRUE----------------------------------------------------------------
# Object count matrix
human_count <- counts(chevreul_sce)
human_count[1:5, 1:5] %>% as.matrix() %>% knitr::kable(format = "pipe")

# Object metadata
human_meta <- colData(chevreul_sce) %>% as.data.frame()
human_meta[1:5, 1:5] %>% as.matrix() %>% knitr::kable(format = "pipe")

## -----------------------------------------------------------------------------
myobject <- SingleCellExperiment::SingleCellExperiment(
    assays = list(counts = counts(chevreul_sce)),
    colData = colData(chevreul_sce),
    mainExpName = "gene"
)

myobject

## ----"start", message=FALSE, eval = FALSE-------------------------------------
#  
#  minimalSceApp(chevreul_sce)
#  

## ----createVignette, eval=FALSE-----------------------------------------------
#  ## Create the vignette
#  library("rmarkdown")
#  system.time(render("chevreul.Rmd", "BiocStyle::html_document"))
#  
#  ## Extract the R code
#  library("knitr")
#  knit("chevreul.Rmd", tangle = TRUE)

## ----reproduce1, echo=FALSE---------------------------------------------------
## Date the vignette was generated
Sys.time()

## ----reproduce2, echo=FALSE---------------------------------------------------
## Processing time in seconds
totalTime <- diff(c(startTime, Sys.time()))
round(totalTime, digits = 3)

## ----reproduce3, echo=FALSE-------------------------------------------------------------------------------------------
## Session info
library("sessioninfo")
options(width = 120)
session_info()

## ----vignetteBiblio, results = "asis", echo = FALSE, warning = FALSE, message = FALSE---------------------------------
## Print bibliography
PrintBibliography(bib, .opts = list(hyperlink = "to.doc", style = "html"))
